Tutorial — SnapPy 3.2 documentation

# Tutorial

The easiest way to learn to use SnapPy is to watch the screencasts available on YouTube:

- Intro and quickstart: an 11 minute video with the basics: Part I and Part II.

- An hour-long demo Practical computation with hyperbolic 3-manifolds, recorded at the Thurston Memorial Conference.

- The SnapPy 2.0 new feature demo.

- SnapPy, SageMath, and Docker are friends with associated materials (4 pages), including homework.

- Notes, problem sheets, and references from the LMS-CMI Research School in Warwick in 2017.

- Another hour-long demo Practical computations with hyperbolic 3-manifolds given at ICERM in 2019.

The key thing to remember when using the SnapPy command shell window is that you can explore objects using introspection and tab-completion:

    In [1]: Manifold? <hit return-key>
    ...instructions for creating a manifold...

So now we create a manifold:

    In [2]: M = Manifold("m004")

But what can we do with it?

    In [3]: M.<hit tab-key>
    ...list of methods...

What does the “cover” method do?

    In [4]: M.cover? <hit return-key>
    ...description of cover method..